% [C,L] = mean_shift(X,s) Mean-shift clustering
%
% In:
%   X: NxD matrix containing N D-dimensional data points rowwise.
%   s: bandwidth.
% Out:
%   C: KxD matrix containing the K cluster modes.
%   L: Nx1 list containing the cluster labels (1 to K). Thus,
%      L(n) = k says point Xn is in cluster k.

function [C,L] = mean_shift(X,s)

